This is an automated email from the git hooks/post-receive script.

Git pushed a commit to branch master
in repository ffmpeg.

commit 6d1e5491955fa86059b195fc6762bfa258871d3f
Author:     Niklas Haas <[email protected]>
AuthorDate: Thu Apr 2 14:24:26 2026 +0200
Commit:     Niklas Haas <[email protected]>
CommitDate: Thu Apr 16 23:25:17 2026 +0200

    swscale/aarch64/ops: use SWS_OP_NEEDED() instead of next->comps.unused
    
    These are basically identical, but the latter is being phased out.
    
    Signed-off-by: Niklas Haas <[email protected]>
---
 libswscale/aarch64/ops_impl_conv.c | 7 +++----
 1 file changed, 3 insertions(+), 4 deletions(-)

diff --git a/libswscale/aarch64/ops_impl_conv.c 
b/libswscale/aarch64/ops_impl_conv.c
index 19dcf9e3c9..a4edbb3b3e 100644
--- a/libswscale/aarch64/ops_impl_conv.c
+++ b/libswscale/aarch64/ops_impl_conv.c
@@ -60,17 +60,16 @@ static int convert_to_aarch64_impl(SwsContext *ctx, const 
SwsOpList *ops, int n,
                                    int block_size, SwsAArch64OpImplParams *out)
 {
     const SwsOp *op = &ops->ops[n];
-    const SwsOp *next = n + 1 < ops->num_ops ? &ops->ops[n + 1] : op;
 
     out->block_size = block_size;
 
     /**
      * Most SwsOp work on fields described by next->comps.unused.
      * The few that don't will override this field later.
      */
     out->mask = 0;
     for (int i = 0; i < 4; i++) {
-        if (!next->comps.unused[i])
+        if (SWS_OP_NEEDED(op, i))
             MASK_SET(out->mask, i, 1);
     }
 
@@ -205,7 +204,7 @@ static int convert_to_aarch64_impl(SwsContext *ctx, const 
SwsOpList *ops, int n,
         out->mask = 0;
         for (int i = 0; i < 4; i++) {
             /* Skip unused or identity rows */
-            if (next->comps.unused[i] || !(op->lin.mask & SWS_MASK_ROW(i)))
+            if (!SWS_OP_NEEDED(op, i) || !(op->lin.mask & SWS_MASK_ROW(i)))
                 continue;
             MASK_SET(out->mask, i, 1);
             for (int j = 0; j < 5; j++) {
@@ -60,17 +60,16 @@ static int convert_to_aarch64_impl(SwsContext *ctx, const 
 
     /**
-     * Most SwsOp work on fields described by next->comps.unused.
+     * Most SwsOp work on fields described by SWS_OP_NEEDED().
      * The few that don't will override this field later.
      */

_______________________________________________
ffmpeg-cvslog mailing list -- [email protected]
To unsubscribe send an email to [email protected]

Reply via email to